# Angular Org Chart

An Angular 13+ library for displaying Organization charts. It's a very lightweigt library with the features currently
not available in any other library. It's written in pure typescript and is developed focussing on Angular projects

## Getting Started

For using the chart, you'll need to do the folloing steps:

### Installation

```
npm install angular13-organization-chart --save
```

### Add the dependency in module

Add `OrgChartModule` in imports

```
import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { OrgChartModule } from 'angular13-organization-chart';
import { AppComponent } from './app.component';

@NgModule({
  declarations: [
    AppComponent
  ],
  imports: [
    BrowserModule,
    OrgChartModule
  ],
  providers: [],
  bootstrap: [AppComponent]
})
export class AppModule { }

```

### Formatting the data in component

The data requires few parameters for displaying the correct chart:

```
interface OrgData {
    name: string;
    type: string;
    cssClass?: string;
    css?: string;
    nameCss?: string;
    typeCss?: string;
    onClick?: () => void;
    children: OrgData[];
}
```

### Example:
![Chart example](src/assets/example_1.png)
![Chart example zoomed out](src/assets/example_2.png)
<br>
(NFT for sale - $29,999,999.99)

## Code:


(Typescript)
```
import {Component} from '@angular/core';
import {OrgData} from './modules/org-chart/orgData';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent {

  orgData: OrgData = {
    name: 'Felines',
    type: 'The Superior Carnivores',
    typeCss: 'color: yellow; font-weight: bold',
    onClick: () => alert('Death to dogs'),
    children: [
      {
        name: 'Big Cats',
        type: 'Predators',
        css: 'background-color: red',
        children: [
          {
            name: 'Lion',
            type: '',
            nameCss: 'font-weight: bold',
            children: []
          },
          {
            name: 'Tiger',
            type: '',
            cssClass: 'yellow-on-hover',
            children: []
          },
          {
            name: 'Cheetah',
            type: '',
            children: []
          }
        ]
      },
      {
        name: 'Small Cats',
        type: 'Domestic',
        children: [
          {
            name: 'House Cat',
            type: '',
            children: []
          },
          {
            name: 'Street Cat',
            type: '',
            children: [
              {
                name: 'Dumb Cat',
                type: '',
                children: [
                  {
                    name: 'Sorry For Bad Example',
                    type: 'Apology',
                    children: []
                  }
                ],
              },
              {
                name: 'Good Cat',
                type: 'Friendly animals',
                children: [
                  {
                    name: 'Binary Search Tree',
                    type: 'BST',
                    children: [
                      {
                        name: '7',
                        type: '',
                        children: [
                          {
                            name: '3',
                            type: '',
                            children: [
                              {
                                name: '2',
                                type: '',
                                children: []
                              },
                              {
                                name: '5',
                                type: '',
                                children: []
                              }
                            ]
                          },
                          {
                            name: '13',
                            type: '',
                            children: [
                              {
                                name: '11',
                                type: '',
                                children: []
                              },
                              {
                                name: '17',
                                type: '',
                                children: []
                              }
                            ]
                          }
                        ]
                      }
                    ]
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        name: 'Fake Cats',
        type: 'Snitches',
        children: [],
        onClick: () => console.log('Google chrome stole some RAM')
      }
    ]
  };

}

```

HTML
```
<angular-org-chart [data]="orgData" #exampleChart="orgChart">

    <!-- OPTIONAL: zoom button with an ugly png -->
    <button zoom-button class="zoom-button" (click)="exampleChart.toggleZoom()">
        <img src="assets/zoom-in-out.png" width="100%" alt="ZoomInOut">
    </button>

</angular-org-chart>

```

CSS
```

:host {
    display: block;
    text-align: center;
    padding: 64px;
}

// ugly css for quick test, use your own!
.zoom-button {
    padding: 0;
    margin: 0;
    border-radius: 50%;
    text-align: center;
    width: 40px;
    height: 40px;
    overflow: hidden;
}

```

### Customizing CSS
`encapsulation: ViewEncapsulation.None`

Encapsulation is disabled, So... go crazy.
Here is [the style sheet](https://github.com/MuaazH/org-chart/tree/master/src/app/modules/org-chart/org-chart-common.scss), you can find all the classes here.
+ PS: To style a single node you can use the optional fields in OrgData.



### Features

* OnClick callback
* Custom styles for individual nodes
* Maintained and lightweight code
* Zoom to see the overview, and hove on nodes to expand them

## Authors

* **Shrey Kumar Jain** - Original Author
* **MuaazH** - Contributed to the problem
